==> semantic_link_labs-0.9.1-py3-none-any.whl: sempy_labs/__init__.py <==
from sempy_labs._job_scheduler import (
    list_item_job_instances,
    list_item_schedules,
)
from sempy_labs._gateways import (
    list_gateway_members,
    list_gateway_role_assigments,
    list_gateways,
    delete_gateway,
    delete_gateway_member,
    delete_gateway_role_assignment,
    create_vnet_gateway,
    update_vnet_gateway,
    update_on_premises_gateway,
    bind_semantic_model_to_gateway,
)
from sempy_labs._authentication import (
    ServicePrincipalTokenProvider,
    service_principal_authentication,
)
from sempy_labs._mirrored_databases import (
    get_mirrored_database_definition,
    get_mirroring_status,
    list_mirrored_databases,
    stop_mirroring,
    start_mirroring,
    create_mirrored_database,
    delete_mirrored_database,
    update_mirrored_database_definition,
    get_tables_mirroring_status,
)
from sempy_labs._managed_private_endpoints import (
    list_managed_private_endpoints,
    create_managed_private_endpoint,
    delete_managed_private_endpoint,
)
from sempy_labs._workloads import (
    list_workloads,
    patch_workload,
)
from sempy_labs._external_data_shares import (
    list_external_data_shares_in_item,
    create_external_data_share,
    revoke_external_data_share,
)
from sempy_labs._ml_models import (
    list_ml_models,
    create_ml_model,
    delete_ml_model,
)
from sempy_labs._ml_experiments import (
    list_ml_experiments,
    create_ml_experiment,
    delete_ml_experiment,
)
from sempy_labs._warehouses import (
    create_warehouse,
    list_warehouses,
    delete_warehouse,
    get_warehouse_columns,
    get_warehouse_tables,
)
from sempy_labs._data_pipelines import (
    list_data_pipelines,
    create_data_pipeline,
    delete_data_pipeline,
    get_data_pipeline_definition,
)
from sempy_labs._eventhouses import (
    create_eventhouse,
    list_eventhouses,
    delete_eventhouse,
)
from sempy_labs._eventstreams import (
    list_eventstreams,
    create_eventstream,
    delete_eventstream,
)
from sempy_labs._kql_querysets import (
    list_kql_querysets,
    create_kql_queryset,
    delete_kql_queryset,
)
from sempy_labs._kql_databases import (
    list_kql_databases,
    create_kql_database,
    delete_kql_database,
)
from sempy_labs._mirrored_warehouses import list_mirrored_warehouses
from sempy_labs._environments import (
    create_environment,
    delete_environment,
    publish_environment,
)
from sempy_labs._clear_cache import (
    clear_cache,
    backup_semantic_model,
    restore_semantic_model,
    copy_semantic_model_backup_file,
    list_backups,
    list_storage_account_files,
)
from sempy_labs._capacity_migration import (
    migrate_spark_settings,
    migrate_workspaces,
    migrate_capacities,
    migrate_notification_settings,
    migrate_access_settings,
    migrate_delegated_tenant_settings,
    migrate_capacity_settings,
    migrate_disaster_recovery_settings,
    migrate_fabric_trial_capacity,
)
from sempy_labs._capacities import (
    create_fabric_capacity,
    resume_fabric_capacity,
    suspend_fabric_capacity,
    update_fabric_capacity,
    delete_fabric_capacity,
    check_fabric_capacity_name_availablility,
    delete_embedded_capacity,
    delete_premium_capacity,
    create_resource_group,
    list_skus,
    list_skus_for_capacity,
    list_subscriptions,
    list_tenants,
    get_subscription,
    check_resource_group_existence,
    list_storage_accounts,
    create_storage_account,
    create_or_update_resource_group,
    list_resource_groups,
    get_resource_group,
)
from sempy_labs._spark import (
    get_spark_settings,
    update_spark_settings,
    list_custom_pools,
    create_custom_pool,
    delete_custom_pool,
    update_custom_pool,
)
from sempy_labs._workspaces import (
    list_workspace_users,
    update_workspace_user,
    add_user_to_workspace,
    delete_user_from_workspace,
    assign_workspace_to_capacity,
    unassign_workspace_from_capacity,
    list_workspace_role_assignments,
)
from sempy_labs._notebooks import (
    get_notebook_definition,
    import_notebook_from_web,
    update_notebook_definition,
    create_notebook,
)
from sempy_labs._sql import (
    ConnectWarehouse,
    ConnectLakehouse,
)
from sempy_labs._workspace_identity import (
    provision_workspace_identity,
    deprovision_workspace_identity,
)
from sempy_labs._deployment_pipelines import (
    list_deployment_pipeline_stage_items,
    list_deployment_pipeline_stages,
    list_deployment_pipelines,
)
from sempy_labs._git import (
    get_git_connection,
    get_git_status,
    commit_to_git,
    initialize_git_connection,
    update_from_git,
    connect_workspace_to_azure_dev_ops,
    connect_workspace_to_github,
    disconnect_workspace_from_git,
)
from sempy_labs._dataflows import (
    list_dataflow_storage_accounts,
    assign_workspace_to_dataflow_storage,
    list_dataflows,
    list_upstream_dataflows,
)
from sempy_labs._connections import (
    list_connections,
    list_item_connections,
    list_connection_role_assignments,
    delete_connection,
    delete_connection_role_assignment,
    create_vnet_connection,
    create_on_prem_connection,
    create_cloud_connection,
)
from sempy_labs._dax import (
    evaluate_dax_impersonation,
    get_dax_query_dependencies,
    get_dax_query_memory_size,
)
from sempy_labs._generate_semantic_model import (
    create_blank_semantic_model,
    create_semantic_model_from_bim,
    deploy_semantic_model,
    get_semantic_model_bim,
    get_semantic_model_size,
    update_semantic_model_from_bim,
    get_semantic_model_definition,
)
from sempy_labs._list_functions import (
    list_reports_using_semantic_model,
    list_semantic_model_object_report_usage,
    list_report_semantic_model_objects,
    list_semantic_model_objects,
    list_shortcuts,
    get_object_level_security,
    list_capacities,
    list_dashboards,
    list_datamarts,
    list_lakehouses,
    list_sql_endpoints,
    update_item,
    list_server_properties,
    list_semantic_model_errors,
)
from sempy_labs._helper_functions import (
    convert_to_friendly_case,
    resolve_environment_id,
    resolve_capacity_id,
    resolve_warehouse_id,
    resolve_dataset_from_report,
    resolve_workspace_capacity,
    create_abfss_path,
    format_dax_object_name,
    create_relationship_name,
    save_as_delta_table,
    generate_embedded_filter,
    get_direct_lake_sql_endpoint,
    resolve_lakehouse_id,
    resolve_lakehouse_name,
    resolve_dataset_id,
    resolve_dataset_name,
    resolve_report_id,
    resolve_report_name,
    is_default_semantic_model,
    resolve_item_type,
    get_capacity_id,
    get_capacity_name,
    resolve_capacity_name,
    get_tenant_id,
)
from sempy_labs._model_bpa_bulk import (
    run_model_bpa_bulk,
    create_model_bpa_semantic_model,
)
from sempy_labs._model_bpa import run_model_bpa
from sempy_labs._model_bpa_rules import model_bpa_rules
from sempy_labs._model_dependencies import (
    measure_dependency_tree,
    get_measure_dependencies,
    get_model_calc_dependencies,
)
from sempy_labs._one_lake_integration import (
    export_model_to_onelake,
)
from sempy_labs._query_scale_out import (
    qso_sync,
    qso_sync_status,
    set_qso,
    list_qso_settings,
    disable_qso,
    set_semantic_model_storage_format,
    set_workspace_default_storage_format,
)
from sempy_labs._refresh_semantic_model import (
    refresh_semantic_model,
    cancel_dataset_refresh,
    get_semantic_model_refresh_history,
)
from sempy_labs._translations import translate_semantic_model
from sempy_labs._vertipaq import (
    vertipaq_analyzer,
    import_vertipaq_analyzer,
)

__all__ = [
    "resolve_warehouse_id",
    "ConnectWarehouse",
    "ConnectLakehouse",
    "update_semantic_model_from_bim",
    "list_connections",
    "get_semantic_model_size",
    "provision_workspace_identity",
    "deprovision_workspace_identity",
    "list_dataflows",
    "copy_semantic_model_backup_file",
    "list_backups",
    "list_storage_account_files",
    "backup_semantic_model",
    "restore_semantic_model",
    "list_semantic_model_object_report_usage",
    "list_report_semantic_model_objects",
    "migrate_spark_settings",
    "create_azure_storage_account",
    "delete_custom_pool",
    "clear_cache",
    "evaluate_dax_impersonation",
    "create_blank_semantic_model",
    "create_semantic_model_from_bim",
    "deploy_semantic_model",
    "get_semantic_model_bim",
    "get_object_level_security",
    "list_dashboards",
    "list_dataflow_storage_accounts",
    "list_lakehouses",
    "list_warehouses",
    "list_workspace_role_assignments",
    "create_warehouse",
    "delete_warehouse",
    "update_item",
    "create_abfss_path",
    "format_dax_object_name",
    "create_relationship_name",
    "save_as_delta_table",
    "generate_embedded_filter",
    "get_direct_lake_sql_endpoint",
    "resolve_lakehouse_id",
    "resolve_lakehouse_name",
    "resolve_dataset_id",
    "resolve_dataset_name",
    "resolve_report_id",
    "resolve_report_name",
    "model_bpa_rules",
    "run_model_bpa",
    "measure_dependency_tree",
    "get_measure_dependencies",
    "get_model_calc_dependencies",
    "export_model_to_onelake",
    "qso_sync",
    "qso_sync_status",
    "set_qso",
    "list_qso_settings",
    "disable_qso",
    "set_semantic_model_storage_format",
    "set_workspace_default_storage_format",
    "refresh_semantic_model",
    "cancel_dataset_refresh",
    "translate_semantic_model",
    "vertipaq_analyzer",
    "import_vertipaq_analyzer",
    "list_semantic_model_objects",
    "list_shortcuts",
    "list_custom_pools",
    "create_custom_pool",
    "update_custom_pool",
    "assign_workspace_to_capacity",
    "unassign_workspace_from_capacity",
    "get_spark_settings",
    "update_spark_settings",
    "add_user_to_workspace",
    "delete_user_from_workspace",
    "update_workspace_user",
    "list_workspace_users",
    "assign_workspace_to_dataflow_storage",
    "list_capacities",
    "is_default_semantic_model",
    "resolve_item_type",
    "get_notebook_definition",
    "import_notebook_from_web",
    "list_reports_using_semantic_model",
    "resolve_workspace_capacity",
    "get_capacity_id",
    "get_capacity_name",
    "resolve_capacity_name",
    "run_model_bpa_bulk",
    "create_model_bpa_semantic_model",
    "list_deployment_pipeline_stage_items",
    "list_deployment_pipeline_stages",
    "list_deployment_pipelines",
    "get_git_connection",
    "get_git_status",
    "commit_to_git",
    "initialize_git_connection",
    "update_from_git",
    "connect_workspace_to_azure_dev_ops",
    "connect_workspace_to_github",
    "disconnect_workspace_from_git",
    "create_environment",
    "delete_environment",
    "publish_environment",
    "resolve_capacity_id",
    "resolve_environment_id",
    "list_item_connections",
    "check_fabric_capacity_name_availablility",
    "delete_fabric_capacity",
    "resume_fabric_capacity",
    "update_fabric_capacity",
    "delete_premium_capacity",
    "suspend_fabric_capacity",
    "delete_embedded_capacity",
    "resolve_dataset_from_report",
    "migrate_workspaces",
    "migrate_capacities",
    "create_fabric_capacity",
    "migrate_capacity_settings",
    "migrate_disaster_recovery_settings",
    "migrate_notification_settings",
    "migrate_access_settings",
    "migrate_delegated_tenant_settings",
    "convert_to_friendly_case",
    "list_mirrored_warehouses",
    "list_kql_databases",
    "create_kql_database",
    "delete_kql_database",
    "create_eventhouse",
    "list_eventhouses",
    "delete_eventhouse",
    "list_data_pipelines",
    "create_data_pipeline",
    "delete_data_pipeline",
    "list_eventstreams",
    "create_eventstream",
    "delete_eventstream",
    "list_kql_querysets",
    "create_kql_queryset",
    "delete_kql_queryset",
    "list_ml_models",
    "create_ml_model",
    "delete_ml_model",
    "list_ml_experiments",
    "create_ml_experiment",
    "delete_ml_experiment",
    "list_sql_endpoints",
    "list_datamarts",
    "get_data_pipeline_definition",
    "list_external_data_shares_in_item",
    "create_external_data_share",
    "revoke_external_data_share",
    "migrate_fabric_trial_capacity",
    "create_resource_group",
    "list_workloads",
    "patch_workload",
    "update_notebook_definition",
    "create_notebook",
    "get_semantic_model_refresh_history",
    "get_warehouse_columns",
    "get_warehouse_tables",
    "list_managed_private_endpoints",
    "create_managed_private_endpoint",
    "delete_managed_private_endpoint",
    "get_dax_query_dependencies",
    "get_dax_query_memory_size",
    "get_mirrored_database_definition",
    "get_mirroring_status",
    "list_mirrored_databases",
    "stop_mirroring",
    "start_mirroring",
    "create_mirrored_database",
    "delete_mirrored_database",
    "update_mirrored_database_definition",
    "get_tables_mirroring_status",
    "list_upstream_dataflows",
    "ServicePrincipalTokenProvider",
    "list_connection_role_assignments",
    "delete_connection",
    "delete_connection_role_assignment",
    "create_vnet_connection",
    "create_on_prem_connection",
    "create_cloud_connection",
    "list_gateway_members",
    "list_gateway_role_assigments",
    "list_gateways",
    "delete_gateway",
    "delete_gateway_member",
    "delete_gateway_role_assignment",
    "create_vnet_gateway",
    "update_vnet_gateway",
    "update_on_premises_gateway",
    "get_semantic_model_definition",
    "get_tenant_id",
    "list_server_properties",
    "bind_semantic_model_to_gateway",
    "list_semantic_model_errors",
    "list_item_job_instances",
    "list_item_schedules",
    "list_skus",
    "list_skus_for_capacity",
    "list_subscriptions",
    "list_tenants",
    "get_subscription",
    "check_resource_group_existence",
    "list_storage_accounts",
    "create_storage_account",
    "create_or_update_resource_group",
    "list_resource_groups",
    "get_resource_group",
    "service_principal_authentication",
]

==> semantic_link_labs-0.9.10-py3-none-any.whl: sempy_labs/__init__.py <==
from sempy_labs._kusto import (
    query_kusto,
    query_workspace_monitoring,
)
from sempy_labs._delta_analyzer_history import (
    delta_analyzer_history,
)
from sempy_labs._dax_query_view import (
    generate_dax_query_view_url,
)
from sempy_labs._mounted_data_factories import (
    list_mounted_data_factories,
    get_mounted_data_factory_definition,
    delete_mounted_data_factory,
)

from sempy_labs._semantic_models import (
    get_semantic_model_refresh_schedule,
    enable_semantic_model_scheduled_refresh,
    delete_semantic_model,
)
from sempy_labs._graphQL import (
    list_graphql_apis,
    create_graphql_api,
)
from sempy_labs._job_scheduler import (
    list_item_job_instances,
    list_item_schedules,
    create_item_schedule_cron,
    create_item_schedule_daily,
    create_item_schedule_weekly,
)
from sempy_labs._delta_analyzer import (
    delta_analyzer,
    get_delta_table_history,
)
from sempy_labs._gateways import (
    list_gateway_members,
    list_gateway_role_assigments,
    list_gateways,
    delete_gateway,
    delete_gateway_member,
    delete_gateway_role_assignment,
    create_vnet_gateway,
    update_vnet_gateway,
    update_on_premises_gateway,
    bind_semantic_model_to_gateway,
)
from sempy_labs._authentication import (
    ServicePrincipalTokenProvider,
    service_principal_authentication,
)
from sempy_labs._mirrored_databases import (
    get_mirrored_database_definition,
    get_mirroring_status,
    list_mirrored_databases,
    stop_mirroring,
    start_mirroring,
    create_mirrored_database,
    delete_mirrored_database,
    update_mirrored_database_definition,
    get_tables_mirroring_status,
)
from sempy_labs._managed_private_endpoints import (
    list_managed_private_endpoints,
    create_managed_private_endpoint,
    delete_managed_private_endpoint,
)
from sempy_labs._workloads import (
    list_workloads,
    patch_workload,
)
from sempy_labs._external_data_shares import (
    list_external_data_shares_in_item,
    create_external_data_share,
    revoke_external_data_share,
)
from sempy_labs._ml_models import (
    list_ml_models,
    create_ml_model,
    delete_ml_model,
)
from sempy_labs._ml_experiments import (
    list_ml_experiments,
    create_ml_experiment,
    delete_ml_experiment,
)
from sempy_labs._warehouses import (
    create_warehouse,
    list_warehouses,
    delete_warehouse,
    get_warehouse_columns,
    get_warehouse_tables,
)
from sempy_labs._data_pipelines import (
    list_data_pipelines,
    create_data_pipeline,
    delete_data_pipeline,
    get_data_pipeline_definition,
)
from sempy_labs._eventhouses import (
    create_eventhouse,
    list_eventhouses,
    delete_eventhouse,
    get_eventhouse_definition,
)
from sempy_labs._eventstreams import (
    list_eventstreams,
    create_eventstream,
    delete_eventstream,
)
from sempy_labs._kql_querysets import (
    list_kql_querysets,
    create_kql_queryset,
    delete_kql_queryset,
)
from sempy_labs._kql_databases import (
    list_kql_databases,
    # create_kql_database,
    delete_kql_database,
)
from sempy_labs._mirrored_warehouses import list_mirrored_warehouses
from sempy_labs._environments import (
    create_environment,
    delete_environment,
    publish_environment,
)
from sempy_labs._clear_cache import (
    clear_cache,
    backup_semantic_model,
    restore_semantic_model,
    copy_semantic_model_backup_file,
    list_backups,
    list_storage_account_files,
)
from sempy_labs._capacity_migration import (
    migrate_workspaces,
    migrate_capacities,
    migrate_fabric_trial_capacity,
)
from sempy_labs._capacities import (
    create_fabric_capacity,
    resume_fabric_capacity,
    suspend_fabric_capacity,
    update_fabric_capacity,
    delete_fabric_capacity,
    check_fabric_capacity_name_availablility,
    delete_embedded_capacity,
    delete_premium_capacity,
    create_resource_group,
    list_skus,
    list_skus_for_capacity,
    list_subscriptions,
    list_tenants,
    get_subscription,
    check_resource_group_existence,
    list_storage_accounts,
    create_storage_account,
    create_or_update_resource_group,
    list_resource_groups,
    get_resource_group,
    list_capacities,
)
from sempy_labs._spark import (
    get_spark_settings,
    update_spark_settings,
    list_custom_pools,
    create_custom_pool,
    delete_custom_pool,
    update_custom_pool,
)
from sempy_labs._workspaces import (
    list_workspace_users,
    update_workspace_user,
    add_user_to_workspace,
    delete_user_from_workspace,
    assign_workspace_to_capacity,
    unassign_workspace_from_capacity,
    list_workspace_role_assignments,
    delete_workspace,
)
from sempy_labs._notebooks import (
    get_notebook_definition,
    import_notebook_from_web,
    update_notebook_definition,
    create_notebook,
)
from sempy_labs._sql import (
    ConnectWarehouse,
    ConnectLakehouse,
    ConnectSQLDatabase,
)
from sempy_labs._sqldatabase import (
    get_sql_database_columns,
    get_sql_database_tables,
    create_sql_database,
    delete_sql_database,
    list_sql_databases,
)
from sempy_labs._workspace_identity import (
    provision_workspace_identity,
    deprovision_workspace_identity,
)
from sempy_labs._deployment_pipelines import (
    list_deployment_pipeline_stage_items,
    list_deployment_pipeline_stages,
    list_deployment_pipelines,
)
from sempy_labs._git import (
    get_git_connection,
    get_git_status,
    commit_to_git,
    initialize_git_connection,
    update_from_git,
    connect_workspace_to_azure_dev_ops,
    connect_workspace_to_github,
    disconnect_workspace_from_git,
    get_my_git_credentials,
    update_my_git_credentials,
)
from sempy_labs._dataflows import (
    list_dataflow_storage_accounts,
    assign_workspace_to_dataflow_storage,
    list_dataflows,
    list_upstream_dataflows,
)
from sempy_labs._connections import (
    list_connections,
    list_item_connections,
    list_connection_role_assignments,
    delete_connection,
    delete_connection_role_assignment,
    create_vnet_connection,
    create_on_prem_connection,
    create_cloud_connection,
)
from sempy_labs._dax import (
    evaluate_dax_impersonation,
    get_dax_query_dependencies,
    get_dax_query_memory_size,
    # dax_perf_test,
    # dax_perf_test_bulk,
)
from sempy_labs._generate_semantic_model import (
    create_blank_semantic_model,
    create_semantic_model_from_bim,
    deploy_semantic_model,
    get_semantic_model_bim,
    get_semantic_model_size,
    update_semantic_model_from_bim,
    get_semantic_model_definition,
)
from sempy_labs._dashboards import (
    list_dashboards,
)
from sempy_labs._list_functions import (
    list_reports_using_semantic_model,
    list_semantic_model_object_report_usage,
    list_report_semantic_model_objects,
    list_semantic_model_objects,
    list_shortcuts,
    get_object_level_security,
    list_datamarts,
    list_lakehouses,
    list_sql_endpoints,
    update_item,
    list_server_properties,
    list_semantic_model_errors,
    list_synonyms,
)
from sempy_labs._helper_functions import (
    convert_to_friendly_case,
    resolve_environment_id,
    resolve_capacity_id,
    resolve_warehouse_id,
    resolve_dataset_from_report,
    resolve_workspace_capacity,
    create_abfss_path,
    format_dax_object_name,
    create_relationship_name,
    save_as_delta_table,
    generate_embedded_filter,
    get_direct_lake_sql_endpoint,
    resolve_lakehouse_id,
    resolve_lakehouse_name,
    resolve_dataset_id,
    resolve_dataset_name,
    resolve_report_id,
    resolve_report_name,
    is_default_semantic_model,
    resolve_item_type,
    get_capacity_id,
    get_capacity_name,
    resolve_capacity_name,
    get_tenant_id,
)
from sempy_labs._model_bpa_bulk import (
    run_model_bpa_bulk,
    create_model_bpa_semantic_model,
)
from sempy_labs._model_bpa import run_model_bpa
from sempy_labs._model_bpa_rules import model_bpa_rules
from sempy_labs._model_dependencies import (
    measure_dependency_tree,
    get_measure_dependencies,
    get_model_calc_dependencies,
)
from sempy_labs._one_lake_integration import (
    export_model_to_onelake,
)
from sempy_labs._query_scale_out import (
    qso_sync,
    qso_sync_status,
    set_qso,
    list_qso_settings,
    disable_qso,
    set_semantic_model_storage_format,
    set_workspace_default_storage_format,
)
from sempy_labs._refresh_semantic_model import (
    refresh_semantic_model,
    cancel_dataset_refresh,
    get_semantic_model_refresh_history,
)
from sempy_labs._translations import translate_semantic_model
from sempy_labs._vertipaq import (
    vertipaq_analyzer,
    import_vertipaq_analyzer,
)

__all__ = [
    "resolve_warehouse_id",
    "ConnectWarehouse",
    "ConnectLakehouse",
    "ConnectSQLDatabase",
    "update_semantic_model_from_bim",
    "list_connections",
    "get_semantic_model_size",
    "provision_workspace_identity",
    "deprovision_workspace_identity",
    "list_dataflows",
    "copy_semantic_model_backup_file",
    "list_backups",
    "list_storage_account_files",
    "backup_semantic_model",
    "restore_semantic_model",
    "list_semantic_model_object_report_usage",
    "list_report_semantic_model_objects",
    "create_azure_storage_account",
    "delete_custom_pool",
    "clear_cache",
    "evaluate_dax_impersonation",
    "create_blank_semantic_model",
    "create_semantic_model_from_bim",
    "deploy_semantic_model",
    "get_semantic_model_bim",
    "get_object_level_security",
    "list_dashboards",
    "list_dataflow_storage_accounts",
    "list_lakehouses",
    "list_warehouses",
    "list_workspace_role_assignments",
    "create_warehouse",
    "delete_warehouse",
    "update_item",
    "create_abfss_path",
    "format_dax_object_name",
    "create_relationship_name",
    "save_as_delta_table",
    "generate_embedded_filter",
    "get_direct_lake_sql_endpoint",
    "resolve_lakehouse_id",
    "resolve_lakehouse_name",
    "resolve_dataset_id",
    "resolve_dataset_name",
    "resolve_report_id",
    "resolve_report_name",
    "model_bpa_rules",
    "run_model_bpa",
    "measure_dependency_tree",
    "get_measure_dependencies",
    "get_model_calc_dependencies",
    "export_model_to_onelake",
    "qso_sync",
    "qso_sync_status",
    "set_qso",
    "list_qso_settings",
    "disable_qso",
    "set_semantic_model_storage_format",
    "set_workspace_default_storage_format",
    "refresh_semantic_model",
    "cancel_dataset_refresh",
    "translate_semantic_model",
    "vertipaq_analyzer",
    "import_vertipaq_analyzer",
    "list_semantic_model_objects",
    "list_shortcuts",
    "list_custom_pools",
    "create_custom_pool",
    "update_custom_pool",
    "assign_workspace_to_capacity",
    "unassign_workspace_from_capacity",
    "get_spark_settings",
    "update_spark_settings",
    "add_user_to_workspace",
    "delete_user_from_workspace",
    "update_workspace_user",
    "list_workspace_users",
    "assign_workspace_to_dataflow_storage",
    "list_capacities",
    "is_default_semantic_model",
    "resolve_item_type",
    "get_notebook_definition",
    "import_notebook_from_web",
    "list_reports_using_semantic_model",
    "resolve_workspace_capacity",
    "get_capacity_id",
    "get_capacity_name",
    "resolve_capacity_name",
    "run_model_bpa_bulk",
    "create_model_bpa_semantic_model",
    "list_deployment_pipeline_stage_items",
    "list_deployment_pipeline_stages",
    "list_deployment_pipelines",
    "get_git_connection",
    "get_git_status",
    "commit_to_git",
    "initialize_git_connection",
    "update_from_git",
    "connect_workspace_to_azure_dev_ops",
    "connect_workspace_to_github",
    "disconnect_workspace_from_git",
    "create_environment",
    "delete_environment",
    "publish_environment",
    "resolve_capacity_id",
    "resolve_environment_id",
    "list_item_connections",
    "check_fabric_capacity_name_availablility",
    "delete_fabric_capacity",
    "resume_fabric_capacity",
    "update_fabric_capacity",
    "delete_premium_capacity",
    "suspend_fabric_capacity",
    "delete_embedded_capacity",
    "resolve_dataset_from_report",
    "migrate_workspaces",
    "migrate_capacities",
    "create_fabric_capacity",
    "convert_to_friendly_case",
    "list_mirrored_warehouses",
    "list_kql_databases",
    # "create_kql_database",
    "delete_kql_database",
    "create_eventhouse",
    "list_eventhouses",
    "delete_eventhouse",
    "list_data_pipelines",
    "create_data_pipeline",
    "delete_data_pipeline",
    "list_eventstreams",
    "create_eventstream",
    "delete_eventstream",
    "list_kql_querysets",
    "create_kql_queryset",
    "delete_kql_queryset",
    "list_ml_models",
    "create_ml_model",
    "delete_ml_model",
    "list_ml_experiments",
    "create_ml_experiment",
    "delete_ml_experiment",
    "list_sql_endpoints",
    "list_datamarts",
    "get_data_pipeline_definition",
    "list_external_data_shares_in_item",
    "create_external_data_share",
    "revoke_external_data_share",
    "migrate_fabric_trial_capacity",
    "create_resource_group",
    "list_workloads",
    "patch_workload",
    "update_notebook_definition",
    "create_notebook",
    "get_semantic_model_refresh_history",
    "get_warehouse_columns",
    "get_warehouse_tables",
    "list_managed_private_endpoints",
    "create_managed_private_endpoint",
    "delete_managed_private_endpoint",
    "get_dax_query_dependencies",
    "get_dax_query_memory_size",
    "get_mirrored_database_definition",
    "get_mirroring_status",
    "list_mirrored_databases",
    "stop_mirroring",
    "start_mirroring",
    "create_mirrored_database",
    "delete_mirrored_database",
    "update_mirrored_database_definition",
    "get_tables_mirroring_status",
    "list_upstream_dataflows",
    "ServicePrincipalTokenProvider",
    "list_connection_role_assignments",
    "delete_connection",
    "delete_connection_role_assignment",
    "create_vnet_connection",
    "create_on_prem_connection",
    "create_cloud_connection",
    "list_gateway_members",
    "list_gateway_role_assigments",
    "list_gateways",
    "delete_gateway",
    "delete_gateway_member",
    "delete_gateway_role_assignment",
    "create_vnet_gateway",
    "update_vnet_gateway",
    "update_on_premises_gateway",
    "get_semantic_model_definition",
    "get_tenant_id",
    "list_server_properties",
    "bind_semantic_model_to_gateway",
    "list_semantic_model_errors",
    "list_item_job_instances",
    "list_item_schedules",
    "list_skus",
    "list_skus_for_capacity",
    "list_subscriptions",
    "list_tenants",
    "get_subscription",
    "check_resource_group_existence",
    "list_storage_accounts",
    "create_storage_account",
    "create_or_update_resource_group",
    "list_resource_groups",
    "get_resource_group",
    "service_principal_authentication",
    "list_synonyms",
    "list_graphql_apis",
    "create_graphql_api",
    "delta_analyzer",
    # "dax_perf_test",
    # "dax_perf_test_bulk",
    "get_semantic_model_refresh_schedule",
    "get_eventhouse_definition",
    "enable_semantic_model_scheduled_refresh",
    "get_delta_table_history",
    "get_sql_database_columns",
    "get_sql_database_tables",
    "create_item_schedule_cron",
    "create_item_schedule_daily",
    "create_item_schedule_weekly",
    "get_my_git_credentials",
    "update_my_git_credentials",
    "list_mounted_data_factories",
    "get_mounted_data_factory_definition",
    "delete_mounted_data_factory",
    "generate_dax_query_view_url",
    "delete_semantic_model",
    "delete_workspace",
    "create_sql_database",
    "delete_sql_database",
    "list_sql_databases",
    "delta_analyzer_history",
    "query_kusto",
    "query_workspace_monitoring",
]
